=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2011-02-22 22:00:45 +0000
+++ CMakeLists.txt	2011-02-24 15:28:06 +0000
@@ -12,7 +12,7 @@
 set (PROJECT_NAME "unity")
 set (UNITY_MAJOR 3)
 set (UNITY_MINOR 4)
-set (UNITY_MICRO 4)
+set (UNITY_MICRO 6)
 set (UNITY_VERSION "${UNITY_MAJOR}.${UNITY_MINOR}.${UNITY_MICRO}")
 set (UNITY_API_VERSION "3.0")
 

=== modified file 'services/CMakeLists.txt'
--- services/CMakeLists.txt	2011-02-17 13:03:25 +0000
+++ services/CMakeLists.txt	2011-02-23 17:22:58 +0000
@@ -2,7 +2,7 @@
 # Panel Service
 #
 find_package(PkgConfig)
-pkg_check_modules(SERVICE_DEPS REQUIRED gobject-2.0 gio-2.0 gtk+-2.0 gthread-2.0 indicator x11)
+pkg_check_modules(SERVICE_DEPS REQUIRED gobject-2.0 gio-2.0 gtk+-2.0 gthread-2.0 indicator x11 gconf-2.0)
 
 execute_process (COMMAND ${PKG_CONFIG_EXECUTABLE} indicator --variable indicatordir OUTPUT_VARIABLE _indicatordir OUTPUT_STRIP_TRAILING_WHITESPACE)
 execute_process (COMMAND ${PKG_CONFIG_EXECUTABLE} indicator --variable iconsdir OUTPUT_VARIABLE _iconsdir OUTPUT_STRIP_TRAILING_WHITESPACE)

=== modified file 'services/panel-a11y.c'
--- services/panel-a11y.c	2011-01-30 17:46:02 +0000
+++ services/panel-a11y.c	2011-02-23 17:22:58 +0000
@@ -16,15 +16,16 @@
  * Authored by: Rodrigo Moya <rodrigo.moya@canonical.com>
  */
 
+#include <gconf/gconf-client.h>
 #include <gio/gio.h>
+
 #include "panel-a11y.h"
 #include "panel-util-accessible.h"
 
 static gboolean a11y_initialized = FALSE;
 
 #define INIT_METHOD "gnome_accessibility_module_init"
-#define DESKTOP_SCHEMA "org.gnome.desktop.interface"
-#define ACCESSIBILITY_ENABLED_KEY "accessibility"
+#define A11Y_GCONF_KEY "/desktop/gnome/interface/accessibility"
 #define AT_SPI_SCHEMA "org.a11y.atspi"
 #define ATK_BRIDGE_LOCATION_KEY "atk-bridge-location"
 
@@ -53,16 +54,19 @@
 static gboolean
 should_enable_a11y (void)
 {
-  GSettings *desktop_settings = NULL;
+  GConfClient *client = NULL;
   gboolean value = FALSE;
-
-  if (!has_gsettings_schema (DESKTOP_SCHEMA))
-    return FALSE;
-
-  desktop_settings = g_settings_new (DESKTOP_SCHEMA);
-  value = g_settings_get_boolean (desktop_settings, ACCESSIBILITY_ENABLED_KEY);
-
-  g_object_unref (desktop_settings);
+  GError *error = NULL;
+
+  client = gconf_client_get_default ();
+  value = gconf_client_get_bool (client, A11Y_GCONF_KEY, &error);
+  if (error != NULL)
+    {
+      g_warning ("Error getting gconf variable %s, a11y disabled by default",
+                 A11Y_GCONF_KEY);
+      g_error_free (error);
+    }
+  g_object_unref (client);
 
   return value;
 }

=== modified file 'src/DeviceLauncherIcon.cpp'
--- src/DeviceLauncherIcon.cpp	2011-02-22 13:46:36 +0000
+++ src/DeviceLauncherIcon.cpp	2011-02-24 14:17:13 +0000
@@ -60,42 +60,15 @@
   
   {
     GIcon *icon;
+    gchar *icon_string;
 
     icon = g_volume_get_icon (_volume);
-    if (G_IS_THEMED_ICON (icon))
-    {
-      const gchar * const *names;
-
-      names = g_themed_icon_get_names (G_THEMED_ICON (icon));
-
-      if (names)
-        SetIconName (names[0]);
-      else
-        SetIconName (DEFAULT_ICON);
-    }
-    else if (G_IS_FILE_ICON (icon))
-    {
-      GFile *file;
-
-      file = g_file_icon_get_file (G_FILE_ICON (icon));
-      if (file)
-      {
-        gchar *path;
-
-        path = g_file_get_path (file);
-        SetIconName (path);
-
-        g_free (path);
-      }
-      else
-        SetIconName (DEFAULT_ICON);
-    }
-    else
-    {
-      SetIconName (DEFAULT_ICON);
-    }
+    icon_string = g_icon_to_string (icon);
+
+    SetIconName (icon_string);
 
     g_object_unref (icon);
+    g_free (icon_string);
   }
   
   SetQuirk (QUIRK_VISIBLE, true);

=== modified file 'src/IconTexture.cpp'
--- src/IconTexture.cpp	2011-02-22 23:37:17 +0000
+++ src/IconTexture.cpp	2011-02-24 13:01:50 +0000
@@ -41,7 +41,8 @@
 {
   _icon_name = g_strdup (icon_name ? icon_name : DEFAULT_ICON);
 
-  LoadIcon ();
+  if (!g_strcmp0 (_icon_name, "") == 0)
+    LoadIcon ();
 }
 
 IconTexture::~IconTexture ()

=== modified file 'src/Launcher.cpp'
--- src/Launcher.cpp	2011-02-24 07:14:51 +0000
+++ src/Launcher.cpp	2011-02-25 15:41:25 +0000
@@ -293,6 +293,10 @@
     _arrow_rtl              = nux::CreateTexture2DFromFile (PKGDATADIR"/launcher_arrow_rtl.png", -1, true);
     _arrow_empty_rtl        = nux::CreateTexture2DFromFile (PKGDATADIR"/launcher_arrow_outline_rtl.png", -1, true);
 
+    for (int i = 0; i < MAX_SUPERKEY_LABELS - 1; i++)
+      _superkey_labels[i] = cairoToTexture2D ((char) ('1' + i), LAUNCHER_ICON_SIZE, LAUNCHER_ICON_SIZE);
+    _superkey_labels[9] = cairoToTexture2D ((char) ('0'), LAUNCHER_ICON_SIZE, LAUNCHER_ICON_SIZE);
+
     _enter_y                = 0;
     _dnd_security           = 15;
     _launcher_drag_delta    = 0;
@@ -313,6 +317,7 @@
     _hide_on_drag_hover     = false;
     _render_drag_window     = false;
     _dnd_window_is_mapped   = false;
+    _drag_edge_touching     = false;
     _backlight_mode         = BACKLIGHT_NORMAL;
     _last_button_press      = 0;
     _selection_atom         = 0;
@@ -352,7 +357,11 @@
 
 Launcher::~Launcher()
 {
-
+  for (int i = 0; i < MAX_SUPERKEY_LABELS; i++)
+  {
+    if (_superkey_labels[i])
+      _superkey_labels[i]->UnReference ();
+  }
 }
 
 /* Introspection */
@@ -363,6 +372,120 @@
 }
 
 void
+Launcher::DrawRoundedRectangle (cairo_t* cr,
+                                double   aspect,
+                                double   x,
+                                double   y,
+                                double   cornerRadius,
+                                double   width,
+                                double   height)
+{
+  double radius = cornerRadius / aspect;
+  
+  // top-left, right of the corner
+  cairo_move_to (cr, x + radius, y);
+  
+  // top-right, left of the corner
+  cairo_line_to (cr, x + width - radius, y);
+  
+  // top-right, below the corner
+  cairo_arc (cr,
+             x + width - radius,
+             y + radius,
+             radius,
+             -90.0f * G_PI / 180.0f,
+             0.0f * G_PI / 180.0f);
+  
+  // bottom-right, above the corner
+  cairo_line_to (cr, x + width, y + height - radius);
+
+  // bottom-right, left of the corner
+  cairo_arc (cr,
+             x + width - radius,
+             y + height - radius,
+             radius,
+             0.0f * G_PI / 180.0f,
+             90.0f * G_PI / 180.0f);
+  
+  // bottom-left, right of the corner
+  cairo_line_to (cr, x + radius, y + height);
+  
+  // bottom-left, above the corner
+  cairo_arc (cr,
+             x + radius,
+             y + height - radius,
+             radius,
+             90.0f * G_PI / 180.0f,
+             180.0f * G_PI / 180.0f);
+  
+  // top-left, right of the corner
+  cairo_arc (cr,
+             x + radius,
+             y + radius,
+             radius,
+             180.0f * G_PI / 180.0f,
+             270.0f * G_PI / 180.0f);
+}
+
+nux::BaseTexture*
+Launcher::cairoToTexture2D (const char label, int width, int height)
+{
+  nux::BaseTexture*     texture  = NULL;
+  nux::CairoGraphics*   cg       = new nux::CairoGraphics (CAIRO_FORMAT_ARGB32,
+                                                           width,
+                                                           height);
+  cairo_t*              cr       = cg->GetContext ();
+  PangoLayout*          layout   = NULL;
+  PangoContext*         pangoCtx = NULL;
+  PangoFontDescription* desc     = NULL;
+  GtkSettings*          settings = gtk_settings_get_default (); // not ref'ed
+  gchar*                fontName = NULL;
+  double                label_x  = 18.0f;
+  double                label_y  = 18.0f;
+  double                label_w  = 18.0f;
+  double                label_h  = 18.0f;
+  double                label_r  = 3.0f;
+
+  cairo_set_operator (cr, CAIRO_OPERATOR_CLEAR);
+  cairo_paint (cr);
+  cairo_scale (cr, 1.0f, 1.0f);
+  cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
+  DrawRoundedRectangle (cr, 1.0f, label_x, label_y, label_r, label_w, label_h);
+  cairo_set_source_rgba (cr, 0.0f, 0.0f, 0.0f, 0.65f);
+  cairo_fill (cr);
+
+  layout = pango_cairo_create_layout (cr);
+  g_object_get (settings, "gtk-font-name", &fontName, NULL);
+  desc = pango_font_description_from_string (fontName);
+  pango_font_description_set_size (desc, 11 * PANGO_SCALE);
+  pango_layout_set_font_description (layout, desc);
+  pango_layout_set_text (layout, &label, 1);
+  pangoCtx = pango_layout_get_context (layout); // is not ref'ed
+
+  PangoRectangle logRect;
+  PangoRectangle inkRect;
+  pango_layout_get_extents (layout, &inkRect, &logRect);
+
+  /* position and paint text */
+  cairo_set_source_rgba (cr, 1.0f, 1.0f, 1.0f, 1.0f);
+  double x = label_x - ((logRect.width / PANGO_SCALE) - label_w) / 2.0f;
+  double y = label_y - ((logRect.height / PANGO_SCALE) - label_h) / 2.0f - 1;
+  cairo_move_to (cr, x, y);
+  pango_cairo_show_layout (cr, layout);
+
+  nux::NBitmapData* bitmap = cg->GetBitmap ();
+  texture = nux::GetThreadGLDeviceFactory()->CreateSystemCapableTexture ();
+  texture->Update (bitmap);
+  delete bitmap;
+  delete cg;
+  g_object_unref (layout);
+  pango_font_description_free (desc);
+  g_free (fontName);
+
+  return texture;
+}
+
+void
 Launcher::startKeyNavMode ()
 {
   _navmod_show_launcher = true;
@@ -1191,6 +1314,7 @@
 void Launcher::StartKeyShowLauncher ()
 {
     _super_show_launcher = true;
+    QueueDraw ();
     SetTimeStruct (&_times[TIME_TAP_SUPER], NULL, ANIM_DURATION_SHORT);
     EnsureHiddenState ();
 }
@@ -1201,9 +1325,10 @@
     clock_gettime (CLOCK_MONOTONIC, &current);  
 
     _super_show_launcher = false;
+    QueueDraw ();
 
     // it's a tap on super
-    if (TimeDelta (&current, &_times[TIME_TAP_SUPER]) < ANIM_DURATION_SHORT)
+    if (TimeDelta (&current, &_times[TIME_TAP_SUPER]) < SUPER_TAP_DURATION)
       ubus_server_send_message (ubus_server_get_default (), UBUS_DASH_EXTERNAL_ACTIVATION, NULL);      
       
     SetupAutohideTimer ();
@@ -1689,6 +1814,10 @@
     // needs to be disconnected
     icon->needs_redraw.connect (sigc::mem_fun(this, &Launcher::OnIconNeedsRedraw));
 
+   guint64 shortcut = icon->GetShortcut ();
+    if (shortcut != 0 && !g_ascii_isdigit ((gchar) shortcut))
+      icon->SetSuperkeyLabel (cairoToTexture2D ((gchar) shortcut, LAUNCHER_ICON_SIZE, LAUNCHER_ICON_SIZE));
+
     AddChild (icon);
 }
 
@@ -2097,6 +2226,51 @@
                 nux::Color (0xFFFFFFFF),
                 arg.alpha,
                 arg.icon->_xform_coords["Glow"]);
+
+  /* draw superkey-shortcut label */ 
+  if (_super_show_launcher)
+  {
+    guint64 shortcut = arg.icon->GetShortcut ();
+
+    /* deal with dynamic labels for places, which can be set via the locale */
+    if (shortcut != 0 && !g_ascii_isdigit ((gchar) shortcut))
+    {
+      RenderIcon (GfxContext,
+                  arg,
+                  arg.icon->GetSuperkeyLabel ()->GetDeviceTexture (),
+                  nux::Color (0xFFFFFFFF),
+                  arg.alpha,
+                  arg.icon->_xform_coords["Tile"]);
+    }
+    else
+    {
+      /* deal with the hardcoded labels used for the first 10 icons on the launcher */
+      gchar key   = (gchar) shortcut;
+      int   index = -1;
+
+      switch (key)
+      {
+        case '1': index = 0; break;
+        case '2': index = 1; break;
+        case '3': index = 2; break;
+        case '4': index = 3; break;
+        case '5': index = 4; break;
+        case '6': index = 5; break;
+        case '7': index = 6; break;
+        case '8': index = 7; break;
+        case '9': index = 8; break;
+        case '0': index = 9; break;
+      }
+
+      if (index != -1)
+        RenderIcon (GfxContext,
+                    arg,
+                    _superkey_labels[index]->GetDeviceTexture (),
+                    nux::Color (0xFFFFFFFF),
+                    arg.alpha,
+                    arg.icon->_xform_coords["Tile"]);
+    }
+  }
 }
 
 void Launcher::DrawContent(nux::GraphicsEngine& GfxContext, bool force_draw)
@@ -2433,7 +2607,10 @@
                                      unsigned long key_state)
 {
   if (_super_show_launcher)
+  {
     RecvKeyPressed (key_sym, key_code, key_state);
+    QueueDraw ();
+  }
 }
 
 void

=== modified file 'src/Launcher.h'
--- src/Launcher.h	2011-02-23 21:01:44 +0000
+++ src/Launcher.h	2011-02-25 15:41:25 +0000
@@ -38,6 +38,11 @@
 #define ANIM_DURATION       200
 #define ANIM_DURATION_LONG  350
 
+#define SUPER_TAP_DURATION  250
+
+#define MAX_SUPERKEY_LABELS 10
+#define LAUNCHER_ICON_SIZE  54
+
 class LauncherModel;
 class QuicklistView;
 class LauncherIcon;
@@ -344,7 +349,21 @@
 
   void SetOffscreenRenderTarget (nux::IntrusiveSP<nux::IOpenGLBaseTexture> texture);
   void RestoreSystemRenderTarget ();
-  
+
+  void
+  DrawRoundedRectangle (cairo_t* cr,
+                        double   aspect,
+                        double   x,
+                        double   y,
+                        double   cornerRadius,
+                        double   width,
+                        double   height);
+
+  nux::BaseTexture*
+  cairoToTexture2D (const char label,
+                    int        width,
+                    int        height);
+
   std::list<char *> StringToUriList (char * input);
 
   nux::HLayout* m_Layout;
@@ -424,6 +443,8 @@
   nux::BaseTexture* _arrow_empty_ltr;
   nux::BaseTexture* _arrow_empty_rtl;
 
+  nux::BaseTexture* _superkey_labels[MAX_SUPERKEY_LABELS];
+
   nux::IntrusiveSP<nux::IOpenGLBaseTexture> _offscreen_drag_texture;
   nux::IntrusiveSP<nux::IOpenGLBaseTexture> _offscreen_progress_texture;
 

=== modified file 'src/LauncherIcon.cpp'
--- src/LauncherIcon.cpp	2011-02-27 08:18:45 +0000
+++ src/LauncherIcon.cpp	2011-02-27 08:25:15 +0000
@@ -73,6 +73,7 @@
   _shortcut = 0;
   
   _emblem = 0;
+  _superkey_label = 0;
 
   _quicklist = new QuicklistView ();
   _quicklist_is_initialized = false;
@@ -106,6 +107,9 @@
   if (_center_stabilize_handle)
     g_source_remove (_center_stabilize_handle);
   _center_stabilize_handle = 0;
+
+  if (_superkey_label)
+    _superkey_label->UnReference ();
 }
 
 bool
@@ -225,16 +229,27 @@
   GtkIconInfo *info;
   nux::BaseTexture *result;
   GError *error = NULL;
-  
-  theme = gtk_icon_theme_get_default ();
-      
+  GIcon *icon;
+
   if (!icon_name)
     icon_name = g_strdup (DEFAULT_ICON);
    
-  info = gtk_icon_theme_lookup_icon (theme,
-                                     icon_name,
-                                     size,
-                                     (GtkIconLookupFlags) 0);            
+  theme = gtk_icon_theme_get_default ();
+  icon = g_icon_new_for_string (icon_name, NULL);
+
+  if (G_IS_ICON (icon))
+  {
+    info = gtk_icon_theme_lookup_by_gicon (theme, icon, size, (GtkIconLookupFlags)0);
+    g_object_unref (icon);
+  }
+  else
+  {   
+    info = gtk_icon_theme_lookup_icon (theme,
+                                       icon_name,
+                                       size,
+                                       (GtkIconLookupFlags) 0);
+  }
+
   if (!info)
   {
     info = gtk_icon_theme_lookup_icon (theme,
@@ -245,13 +260,16 @@
         
   if (gtk_icon_info_get_filename (info) == NULL)
   {
+    gtk_icon_info_free (info);
+
     info = gtk_icon_theme_lookup_icon (theme,
                                        DEFAULT_ICON,
                                        size,
                                        (GtkIconLookupFlags) 0);
   }
-  
+
   pbuf = gtk_icon_info_load_icon (info, &error);
+  gtk_icon_info_free (info);
 
   if (GDK_IS_PIXBUF (pbuf))
   {
@@ -688,6 +706,24 @@
   needs_redraw.emit (this);
 }
 
+void
+LauncherIcon::SetSuperkeyLabel (nux::BaseTexture* label)
+{
+  if (_superkey_label == label)
+    return;
+  
+  if (_superkey_label)
+    _superkey_label->UnReference ();
+  
+  _superkey_label = label;  
+}
+
+nux::BaseTexture*
+LauncherIcon::GetSuperkeyLabel ()
+{
+  return _superkey_label;
+}
+
 void 
 LauncherIcon::SetEmblemIconName (const char *name)
 {

=== modified file 'src/LauncherIcon.h'
--- src/LauncherIcon.h	2011-02-22 17:05:31 +0000
+++ src/LauncherIcon.h	2011-02-23 23:18:44 +0000
@@ -176,6 +176,8 @@
     void SetSortPriority (int priority);
 
     void SetEmblem (nux::BaseTexture *emblem);
+    void SetSuperkeyLabel (nux::BaseTexture* label);
+    nux::BaseTexture* GetSuperkeyLabel ();
 
     virtual std::list<DbusmenuMenuitem *> GetMenus ();
     virtual nux::BaseTexture * GetTextureForSize (int size) = 0;
@@ -258,6 +260,7 @@
     IconType         _icon_type;
     
     nux::BaseTexture* _emblem;
+    nux::BaseTexture* _superkey_label;
     
     bool             _quirks[QUIRK_LAST];
     struct timespec  _quirk_times[QUIRK_LAST];

=== modified file 'src/PanelIndicatorObjectEntryView.cpp'
--- src/PanelIndicatorObjectEntryView.cpp	2011-02-15 16:45:30 +0000
+++ src/PanelIndicatorObjectEntryView.cpp	2011-02-23 17:02:01 +0000
@@ -212,7 +212,7 @@
 
   if (_proxy->GetPixbuf () && _proxy->icon_visible)
   {
-    gdk_cairo_set_source_pixbuf (cr, pixbuf, x, (height - gdk_pixbuf_get_height (pixbuf))/2);
+    gdk_cairo_set_source_pixbuf (cr, pixbuf, x, (int)((height - gdk_pixbuf_get_height (pixbuf))/2));
     cairo_paint_with_alpha (cr, _proxy->icon_sensitive ? 1.0 : 0.5);
 
     x += icon_width + SPACING;
@@ -230,7 +230,7 @@
                            textshadowcol.GetGreen (),
                            textshadowcol.GetBlue (),
                            1.0f - textshadowcol.GetRed ());
-    cairo_move_to (cr, x, ((height - text_height)/2)-1);
+    cairo_move_to (cr, x, (int)(((height - text_height)/2)+1));
     pango_cairo_show_layout (cr, layout);
     cairo_stroke (cr);
 
@@ -240,7 +240,7 @@
                            textcol.GetGreen (),
                            textcol.GetBlue (),
                            _proxy->label_sensitive ? 1.0f : 0.0f);
-    cairo_move_to (cr, x, (height - text_height)/2);
+    cairo_move_to (cr, x, (int)((height - text_height)/2));
     pango_cairo_show_layout (cr, layout);
     cairo_stroke (cr);
   }
@@ -295,7 +295,7 @@
   PanelStyle *style = PanelStyle::GetDefault ();
   nux::Color bgtop = style->GetBackgroundTop ();
   nux::Color bgbot = style->GetBackgroundBottom ();
-  nux::Color line = style->GetTextShadow ();
+  nux::Color line = style->GetLineColor ();
 
   cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 

=== modified file 'src/PanelStyle.cpp'
--- src/PanelStyle.cpp	2011-02-17 09:56:22 +0000
+++ src/PanelStyle.cpp	2011-02-23 17:02:01 +0000
@@ -81,11 +81,16 @@
   _text.SetBlue ((float) style->text[0].blue / (float) 0xffff);
   _text.SetAlpha (1.0f);
 
-  _text_shadow.SetRed ((float) style->dark[0].red / (float) 0xffff);
-  _text_shadow.SetGreen ((float) style->dark[0].green / (float) 0xffff);
-  _text_shadow.SetBlue ((float) style->dark[0].blue / (float) 0xffff);
+  _text_shadow.SetRed ((float) style->text[3].red / (float) 0xffff);
+  _text_shadow.SetGreen ((float) style->text[3].green / (float) 0xffff);
+  _text_shadow.SetBlue ((float) style->text[3].blue / (float) 0xffff);
   _text_shadow.SetAlpha (1.0f);
 
+  _line.SetRed ((float) style->dark[0].red / (float) 0xffff);
+  _line.SetGreen ((float) style->dark[0].green / (float) 0xffff);
+  _line.SetBlue ((float) style->dark[0].blue / (float) 0xffff);
+  _line.SetAlpha (1.0f);
+
   _bg_top.SetRed ((float) style->bg[1].red / (float) 0xffff);
   _bg_top.SetGreen ((float) style->bg[1].green / (float) 0xffff);
   _bg_top.SetBlue ((float) style->bg[1].blue / (float) 0xffff);
@@ -123,6 +128,12 @@
   return _text_shadow;
 }
 
+nux::Color&
+PanelStyle::GetLineColor ()
+{
+  return _line;
+}
+
 void
 PanelStyle::OnStyleChanged (GObject*    gobject,
                             GParamSpec* pspec,

=== modified file 'src/PanelStyle.h'
--- src/PanelStyle.h	2011-02-17 09:56:22 +0000
+++ src/PanelStyle.h	2011-02-23 17:02:01 +0000
@@ -52,6 +52,7 @@
     nux::Color& GetBackgroundTop ();
     nux::Color& GetBackgroundBottom ();
     nux::Color& GetTextShadow ();
+    nux::Color& GetLineColor ();
 
     GdkPixbuf * GetBackground (int width, int height);
 
@@ -74,6 +75,7 @@
     nux::Color         _bg_top;
     nux::Color         _bg_bottom;
     nux::Color         _text_shadow;
+    nux::Color         _line;
 };
 
 #endif // PANEL_STYLE_H

=== modified file 'src/PlaceEntry.h'
--- src/PlaceEntry.h	2011-02-22 13:14:15 +0000
+++ src/PlaceEntry.h	2011-02-24 13:25:05 +0000
@@ -86,6 +86,8 @@
   virtual DeeModel * GetResultsModel () = 0;
 
   virtual DeeModel * GetGlobalResultsModel () = 0;
+  virtual DeeModel * GetGlobalGroupsModel () = 0;
+
   // Signals
 
   sigc::signal<void, bool>                    active_changed;

=== modified file 'src/PlaceEntryHome.cpp'
--- src/PlaceEntryHome.cpp	2011-02-22 13:14:15 +0000
+++ src/PlaceEntryHome.cpp	2011-02-24 13:36:26 +0000
@@ -87,7 +87,7 @@
     iter = dee_model_append (_groups_model, "", text, entry->GetIcon ());
     _model_to_group[entry->GetGlobalResultsModel ()] = dee_model_get_position (_groups_model,
                                                                                iter);
-
+    _model_to_group_model[entry->GetGlobalResultsModel ()] = entry->GetGlobalGroupsModel ();
     g_signal_connect (entry->GetGlobalResultsModel (), "row-added",
                       (GCallback)&PlaceEntryHome::OnResultAdded, this);
     g_signal_connect (entry->GetGlobalResultsModel (), "row-removed",
@@ -110,6 +110,10 @@
 void
 PlaceEntryHome::OnResultAdded (DeeModel *model, DeeModelIter *iter, PlaceEntryHome *self)
 {
+  // FIXME: This is a hack
+  if (dee_model_get_uint32 (model, iter, RESULT_GROUP_ID) == 5)
+    return;
+
   dee_model_append (self->_results_model,
                     dee_model_get_string (model, iter, RESULT_URI),
                     dee_model_get_string (model, iter, RESULT_ICON),
@@ -126,6 +130,10 @@
   DeeModelIter *iter, *end;
   const char   *uri;
 
+  // FIXME: This is a hack
+  if (dee_model_get_uint32 (model, it, RESULT_GROUP_ID) == 5)
+    return;
+
   uri = dee_model_get_string (model, it, RESULT_URI);
 
   iter = dee_model_get_first_iter (self->_results_model);
@@ -152,7 +160,7 @@
 const gchar *
 PlaceEntryHome::GetName ()
 {
-  return _("Global Search");
+  return "";
 }
 
 const gchar *

=== modified file 'src/PlaceEntryHome.h'
--- src/PlaceEntryHome.h	2011-02-22 13:14:15 +0000
+++ src/PlaceEntryHome.h	2011-02-24 13:25:05 +0000
@@ -65,6 +65,7 @@
   DeeModel * GetResultsModel ();
 
   DeeModel * GetGlobalResultsModel () { return NULL; };
+  DeeModel * GetGlobalGroupsModel () { return NULL; };
 
 private:
   void LoadExistingEntries ();
@@ -85,6 +86,7 @@
   std::map<char *, gchar *> _hints;
 
   std::map<DeeModel *, int> _model_to_group;
+  std::map<DeeModel *, DeeModel *> _model_to_group_model;
   std::vector<PlaceEntry *> _entries;
 };
 

=== modified file 'src/PlaceEntryRemote.cpp'
--- src/PlaceEntryRemote.cpp	2011-02-22 13:14:15 +0000
+++ src/PlaceEntryRemote.cpp	2011-02-24 13:25:05 +0000
@@ -55,6 +55,7 @@
   _groups_model (NULL),
   _results_model (NULL),
   _global_results_model (NULL),
+  _global_groups_model (NULL),
   _previous_search (NULL),
   _previous_section (G_MAXUINT32)
 {
@@ -76,6 +77,7 @@
   g_object_unref (_groups_model);
   g_object_unref (_results_model);
   g_object_unref (_global_results_model);
+  g_object_unref (_global_groups_model);
 }
 
 void
@@ -331,6 +333,12 @@
   return _global_results_model;
 }
 
+DeeModel *
+PlaceEntryRemote::GetGlobalGroupsModel ()
+{
+  return _global_groups_model;
+}
+
 /* Other methods */
 bool
 PlaceEntryRemote::IsValid ()
@@ -379,7 +387,7 @@
     _state_changed = true;
   }
   
-  if (g_strcmp0 (_icon, icon) != 0)
+  if (g_strcmp0 ("", icon) != 0 && g_strcmp0 (_icon, icon) != 0)
   {
     g_free (_icon);
     _icon = g_strdup (icon);
@@ -449,7 +457,17 @@
   // FIXME: Spec says if global_renderer == "", then ShowInGlobal () == false, but currently
   //        both places return ""
 
-  // FIXME: Handle global groups model name
+  if (!DEE_IS_SHARED_MODEL (_global_groups_model) ||
+      g_strcmp0 (dee_shared_model_get_swarm_name (DEE_SHARED_MODEL (_global_groups_model)), global_groups_model) != 0)
+  {
+    if (DEE_IS_SHARED_MODEL (_global_groups_model))
+      g_object_unref (_global_groups_model);
+
+    _global_groups_model = dee_shared_model_new (global_groups_model);
+    dee_model_set_schema (_global_groups_model, "s", "s", "s", NULL);
+
+    _global_renderer_changed = true;
+  }
 
   if (!DEE_IS_SHARED_MODEL (_global_results_model) ||
       g_strcmp0 (dee_shared_model_get_swarm_name (DEE_SHARED_MODEL (_global_results_model)), global_results_model) != 0)

=== modified file 'src/PlaceEntryRemote.h'
--- src/PlaceEntryRemote.h	2011-02-22 13:14:15 +0000
+++ src/PlaceEntryRemote.h	2011-02-24 13:25:05 +0000
@@ -67,6 +67,7 @@
   DeeModel * GetResultsModel ();
 
   DeeModel * GetGlobalResultsModel ();
+  DeeModel * GetGlobalGroupsModel ();
 
   /* Other methods */
   bool          IsValid ();
@@ -119,6 +120,7 @@
   DeeModel *_results_model;
 
   DeeModel *_global_results_model;
+  DeeModel *_global_groups_model;
 
   gchar    *_previous_search;
   guint32   _previous_section;

=== modified file 'src/PlacesGroup.cpp'
--- src/PlacesGroup.cpp	2011-02-25 15:21:48 +0000
+++ src/PlacesGroup.cpp	2011-02-25 15:41:25 +0000
@@ -51,23 +51,22 @@
   //~ OnMouseEnter.connect (sigc::mem_fun (this, &PlacesGroup::RecvMouseEnter));
   //~ OnMouseLeave.connect (sigc::mem_fun (this, &PlacesGroup::RecvMouseLeave));
 
+  _icon_texture = new IconTexture ("", 24);
+  _icon_texture->SetMinimumSize (24, 24);
+
   _label = new nux::StaticCairoText ("", NUX_TRACKER_LOCATION);
-  _label->SetFont ("Ubuntu normal 11");
   _label->SetTextEllipsize (nux::StaticCairoText::NUX_ELLIPSIZE_END);
   _label->SetTextAlignment (nux::StaticCairoText::NUX_ALIGN_LEFT);
-  _label->SetMaximumWidth (320);
-  _label->SetMinimumWidth (1);
 
   _title = new nux::StaticCairoText ("", NUX_TRACKER_LOCATION);
-  _title->SetFont ("Ubuntu normal 11");
   _title->SetTextEllipsize (nux::StaticCairoText::NUX_ELLIPSIZE_END);
-  _title->SetTextAlignment (nux::StaticCairoText::NUX_ALIGN_RIGHT);
-  _title->SetMaximumWidth (320);
-  _title->SetMinimumWidth (1);
+  _title->SetTextAlignment (nux::StaticCairoText::NUX_ALIGN_LEFT);
 
   _header_layout = new nux::HLayout (NUX_TRACKER_LOCATION);
+  _header_layout->SetHorizontalInternalMargin (12);
 
-  _header_layout->AddView (_title, 0, nux::MINOR_POSITION_TOP, nux::MINOR_SIZE_FULL);
+  _header_layout->AddView (_icon_texture, 0, nux::MINOR_POSITION_CENTER, nux::MINOR_SIZE_FIX);
+  _header_layout->AddView (_title, 0, nux::MINOR_POSITION_CENTER, nux::MINOR_SIZE_FIX);
   _header_layout->AddSpace (1, 1);
 
   // FIXME: We don't want to show this as it does nothing right now
@@ -102,12 +101,15 @@
 
 void PlacesGroup::SetTitle (const char *title)
 {
-  _title_string = g_strdup (title);
+  const gchar *temp = "<big>%s</big>";
+
+  _title_string = g_strdup_printf (temp, title);
   UpdateTitle ();
 }
 
 void PlacesGroup::SetEmblem (const char *path_to_emblem)
 {
+  _icon_texture->SetByIconName (path_to_emblem, 24);
 }
 
 void PlacesGroup::AddLayout (nux::Layout *layout)

=== modified file 'src/PlacesGroup.h'
--- src/PlacesGroup.h	2011-02-21 23:00:30 +0000
+++ src/PlacesGroup.h	2011-02-24 13:01:50 +0000
@@ -36,6 +36,8 @@
 #include <sigc++/functors/ptr_fun.h>
 #include <sigc++/functors/mem_fun.h>
 
+#include "IconTexture.h"
+
 class PlacesGroup : public nux::View
 {
 public:
@@ -63,6 +65,7 @@
   unsigned int _visible_items;
 
   nux::Layout *_content;
+  IconTexture  *_icon_texture;
   nux::VLayout *_group_layout;
   nux::HLayout *_header_layout;
 

=== modified file 'src/PlacesResultsController.cpp'
--- src/PlacesResultsController.cpp	2011-02-22 23:37:17 +0000
+++ src/PlacesResultsController.cpp	2011-02-24 13:01:50 +0000
@@ -153,13 +153,14 @@
 }
 
 PlacesGroup *
-PlacesResultsController::CreateGroup (const char *groupname)
+PlacesResultsController::CreateGroup (const char *groupname, const char *icon)
 {
   PlacesSettings *settings = PlacesSettings::GetDefault ();
 
   PlacesGroup *newgroup = new PlacesGroup (NUX_TRACKER_LOCATION);
   newgroup->SinkReference ();
   newgroup->SetTitle (groupname);
+  newgroup->SetEmblem (icon);
   newgroup->SetRowHeight (92);
   newgroup->SetItemDetail (1, 100);
   newgroup->SetExpanded (true);

=== modified file 'src/PlacesResultsController.h'
--- src/PlacesResultsController.h	2011-02-09 20:44:45 +0000
+++ src/PlacesResultsController.h	2011-02-24 13:01:50 +0000
@@ -46,7 +46,8 @@
   void RemoveResultFromGroup (const char *groupname,
                               void       *_id);
   void Clear                 ();
-  PlacesGroup  *CreateGroup  (const char *groupname);
+  PlacesGroup  *CreateGroup  (const char *groupname,
+                              const char *icon="");
 protected:
   const gchar* GetName ();
   void AddProperties (GVariantBuilder *builder);

=== modified file 'src/PlacesResultsView.cpp'
--- src/PlacesResultsView.cpp	2011-02-23 16:37:57 +0000
+++ src/PlacesResultsView.cpp	2011-02-25 15:41:25 +0000
@@ -36,6 +36,8 @@
   _layout = new nux::VLayout ("", NUX_TRACKER_LOCATION);
 
   _layout->SetContentDistribution(nux::MAJOR_POSITION_TOP);
+  _layout->SetHorizontalExternalMargin (14);
+  _layout->SetVerticalInternalMargin (14);
 
 
   /*nux::GridHLayout *grid_h_layout ((new nux::GridHLayout (NUX_TRACKER_LOCATION)));

=== modified file 'src/PlacesSearchBar.cpp'
--- src/PlacesSearchBar.cpp	2011-02-24 07:14:51 +0000
+++ src/PlacesSearchBar.cpp	2011-02-25 15:41:25 +0000
@@ -48,15 +48,38 @@
   _bg_layer = new nux::ColorLayer (nux::Color (0xff595853), true);
 
   _layout = new nux::HLayout (NUX_TRACKER_LOCATION);
+  _layout->SetHorizontalInternalMargin (12);
+
+  _search_icon = new IconTexture ("find", 32);
+  _layout->AddView (_search_icon, 0);
+
+  _layered_layout = new nux::LayeredLayout ();
+
+  _hint = new nux::StaticCairoText (" ");
+  _hint->SetTextColor (nux::Color (1.0f, 1.0f, 1.0f, 0.5f));
+  _layered_layout->AddLayer (_hint);
 
   _pango_entry = new nux::TextEntry ("", NUX_TRACKER_LOCATION);
   _pango_entry->sigTextChanged.connect (sigc::mem_fun (this, &PlacesSearchBar::OnSearchChanged));
-  _layout->AddView (_pango_entry, 1, nux::MINOR_POSITION_CENTER, nux::MINOR_SIZE_FULL);
+  _pango_entry->SetMinimumHeight (30);
+  _layered_layout->AddLayer (_pango_entry);
+
+  _layered_layout->SetPaintAll (true);
+  _layered_layout->SetActiveLayerN (1);
+
+  _layout->AddView (_layered_layout, 1, nux::MINOR_POSITION_CENTER, nux::MINOR_SIZE_FULL);
 
   _layout->SetVerticalExternalMargin (18);
   _layout->SetHorizontalExternalMargin (18);
   
   SetLayout (_layout);
+
+  SetCompositionLayout (_layout);
+
+  g_signal_connect (gtk_settings_get_default (), "notify::gtk-font-name",
+                    G_CALLBACK (OnFontChanged), this);
+  OnFontChanged (NULL, NULL, this);
+
 }
 
 PlacesSearchBar::~PlacesSearchBar ()
@@ -123,19 +146,10 @@
 }
 
 void
-PlacesSearchBar::PreLayoutManagement ()
-{
-  nux::View::PreLayoutManagement ();
-}
-
-long
-PlacesSearchBar::PostLayoutManagement (long LayoutResult)
-{
-  return nux::View::PostLayoutManagement (LayoutResult);
-}
-
-void
-PlacesSearchBar::SetActiveEntry (PlaceEntry *entry, guint section_id, const char *search_string, bool ignore)
+PlacesSearchBar::SetActiveEntry (PlaceEntry *entry,
+                                 guint       section_id,
+                                 const char *search_string,
+                                 bool        ignore_search)
 {
    std::map<gchar *, gchar *> hints;
 
@@ -144,18 +158,25 @@
   if (_entry)
   {
     // i18n: This is for a dynamic place name i.e. "Search Files & Folders"
-    const gchar *search_template = _("Search %s");
+    const gchar *search_template = _("<span font_size='x-small' font_style='italic'>Search %s</span>");
     gchar       *res;
-
-    res = g_strdup_printf (search_template, _entry->GetName ());
-    
-    if (!ignore)
+    gchar       *tmp;
+
+    tmp = g_markup_escape_text (entry->GetName (), -1);
+    res = g_strdup_printf (search_template, tmp);
+
+    _hint->SetText (res);
+
+    if (!ignore_search)
     {
       _entry->SetActiveSection (section_id);
       _entry->SetSearch (search_string ? search_string : "", hints);
     }
+    
     _pango_entry->SetText (search_string ? search_string : "");
+    
     g_free (res);
+    g_free (tmp);
   }
   else
   {
@@ -166,6 +187,8 @@
 void
 PlacesSearchBar::OnSearchChanged (nux::TextEntry *text_entry)
 {
+  bool is_empty;
+
   if (_live_search_timeout)
     g_source_remove (_live_search_timeout);
   
@@ -175,6 +198,11 @@
 
   search_changed.emit (_pango_entry->GetText ().c_str ());
 
+
+  is_empty = g_strcmp0 (_pango_entry->GetText ().c_str (), "") == 0;
+  _hint->SetVisible (is_empty);
+
+  _hint->QueueDraw ();
   _pango_entry->QueueDraw ();
   QueueDraw ();
 }
@@ -199,6 +227,36 @@
   _live_search_timeout = 0;
 }
 
+void
+PlacesSearchBar::OnFontChanged (GObject *object, GParamSpec *pspec, PlacesSearchBar *self)
+{
+#define HOW_LARGE 10
+  GtkSettings          *settings;
+  gchar                *font_name = NULL;
+  PangoFontDescription *desc;
+  gint                  size;
+  gchar                *font_desc;
+
+  settings = gtk_settings_get_default ();
+  g_object_get (settings, "gtk-font-name", &font_name, NULL);
+
+  desc = pango_font_description_from_string (font_name);
+  self->_pango_entry->SetFontFamily (pango_font_description_get_family (desc));
+
+  size = pango_font_description_get_size (desc);
+  size /= pango_font_description_get_size_is_absolute (desc) ? 1 : PANGO_SCALE;
+  self->_pango_entry->SetFontSize ( size + HOW_LARGE);
+
+  self->_pango_entry->SetFontOptions (gdk_screen_get_font_options (gdk_screen_get_default ()));
+
+  font_desc = g_strdup_printf ("%s %d", pango_font_description_get_family (desc), size + HOW_LARGE);
+  self->_hint->SetFont (font_desc);
+
+  pango_font_description_free (desc);
+  g_free (font_name);
+  g_free (font_desc);
+}
+
 static void
 draw_rounded_rect (cairo_t* cr,
                    double   aspect,
@@ -253,6 +311,7 @@
                radius,
                180.0f * G_PI / 180.0f,
                270.0f * G_PI / 180.0f);
+  cairo_close_path (cr);
 }
 
 void
@@ -278,17 +337,27 @@
   cairo_translate (cr, 0.5, 0.5);
   cairo_set_line_width (cr, 1.0);
 
-  cairo_set_source_rgba (cr, 0.0f, 0.0f, 0.0f, 1.0f);
-
   draw_rounded_rect (cr, 1.0f, x, y, RADIUS, width, height);
 
-  cairo_close_path (cr);
-
+  cairo_set_source_rgba (cr, 0.0f, 0.0f, 0.0f, 0.8f);
   cairo_fill_preserve (cr);
 
   cairo_set_source_rgba (cr, 1.0f, 1.0f, 1.0f, 0.8f);
   cairo_stroke (cr);
 
+  //FIXME: This is until we get proper glow
+  draw_rounded_rect (cr, 1.0f, x-1, y-1, RADIUS, width+2, height+2);
+  cairo_set_source_rgba (cr, 1.0f, 1.0f, 1.0f, 0.4f);
+  cairo_stroke (cr);
+
+  draw_rounded_rect (cr, 1.0f, x-2, y-2, RADIUS, width+4, height+4);
+  cairo_set_source_rgba (cr, 1.0f, 1.0f, 1.0f, 0.2f);
+  cairo_stroke (cr);
+
+  draw_rounded_rect (cr, 1.0f, x-3, y-3, RADIUS, width+6, height+6);
+  cairo_set_source_rgba (cr, 1.0f, 1.0f, 1.0f, 0.1f);
+  cairo_stroke (cr);
+
   cairo_destroy (cr);
 
   nux::NBitmapData* bitmap =  cairo_graphics.GetBitmap();

=== modified file 'src/PlacesSearchBar.h'
--- src/PlacesSearchBar.h	2011-02-24 07:14:51 +0000
+++ src/PlacesSearchBar.h	2011-02-25 15:41:25 +0000
@@ -20,8 +20,10 @@
 #ifndef PLACES_SEARCH_BAR_H
 #define PLACES_SEARCH_BAR_H
 
+#include <Nux/LayeredLayout.h>
+#include <Nux/TextureArea.h>
 #include <Nux/View.h>
-#include <Nux/TextureArea.h>
+
 #include <NuxGraphics/GraphicsEngine.h>
 
 #include "Introspectable.h"
@@ -32,6 +34,10 @@
 #include "PlaceEntry.h"
 
 class PlacesView;
+#include <gtk/gtk.h>
+
+#include "IconTexture.h"
+#include "StaticCairoText.h"
 
 class PlacesSearchBar : public Introspectable, public nux::View
 {
@@ -44,10 +50,10 @@
   virtual void Draw (nux::GraphicsEngine& GfxContext, bool force_draw);
   virtual void DrawContent (nux::GraphicsEngine &GfxContext, bool force_draw);
 
-  virtual void PreLayoutManagement ();
-  virtual long PostLayoutManagement (long LayoutResult);
-
-  void SetActiveEntry (PlaceEntry *entry, guint section_id, const char *search_string, bool ignore=false);
+  void SetActiveEntry (PlaceEntry *entry,
+                       guint       section_id,
+                       const char *search_string,
+                       bool        ignore=false);
 
   sigc::signal<void, const char *> search_changed;
   
@@ -63,10 +69,13 @@
   void EmitLiveSearch ();
 
   static bool OnLiveSearchTimeout (PlacesSearchBar *self);
+  static void OnFontChanged (GObject *object, GParamSpec *pspec, PlacesSearchBar *self);
 
 private:
   nux::AbstractPaintLayer *_bg_layer;
   nux::HLayout            *_layout;
+  nux::LayeredLayout      *_layered_layout;
+  nux::StaticCairoText    *_hint;
   nux::TextEntry          *_pango_entry;
   int _last_width;
   int _last_height;
@@ -74,6 +83,7 @@
   guint                    _live_search_timeout;
 
   friend class PlacesView;
+  IconTexture             *_search_icon;
 };
 
 #endif

=== modified file 'src/PlacesView.cpp'
--- src/PlacesView.cpp	2011-02-24 07:14:51 +0000
+++ src/PlacesView.cpp	2011-02-25 15:41:25 +0000
@@ -142,9 +142,6 @@
 void
 PlacesView::SetActiveEntry (PlaceEntry *entry, guint section_id, const char *search_string, bool signal)
 {
-  if ((!entry && _entry == _home_entry) && g_strcmp0 (search_string, "") == 0)
-    return;
-
   if (signal)
     entry_changed.emit (entry);
 
@@ -181,7 +178,11 @@
   {
     _results_controller->CreateGroup (dee_model_get_string (groups,
                                                             iter,
-                                                            PlaceEntry::GROUP_NAME));
+                                                            PlaceEntry::GROUP_NAME),
+                                      dee_model_get_string (groups,
+                                                            iter,
+                                                            PlaceEntry::GROUP_ICON));
+    g_debug ("%s", dee_model_get_string (groups, iter, PlaceEntry::GROUP_ICON));
     iter = dee_model_next (groups, iter);
   }
 
@@ -231,7 +232,12 @@
 void
 PlacesView::OnGroupAdded (DeeModel *model, DeeModelIter *iter, PlacesView *self)
 {
-  g_debug ("GroupAdded: %s", dee_model_get_string (model, iter, 1));
+  self->_results_controller->CreateGroup (dee_model_get_string (model,
+                                                                iter,
+                                                                PlaceEntry::GROUP_NAME),
+                                          dee_model_get_string (model,
+                                                                iter,
+                                                                PlaceEntry::GROUP_ICON));
 }
 
 

=== modified file 'src/StaticCairoText.cpp'
--- src/StaticCairoText.cpp	2011-02-22 23:37:17 +0000
+++ src/StaticCairoText.cpp	2011-02-23 23:26:45 +0000
@@ -162,13 +162,21 @@
   gfxContext.GetRenderStates ().GetBlend (alpha, src, dest);
   gfxContext.GetRenderStates ().SetBlend (true, GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
 
+  Color col = Color::Black;
+  col.SetAlpha (0.0f);
+  gfxContext.QRP_Color (base.x,
+      base.y,
+      base.width,
+      base.height,
+      col);
+
   gfxContext.QRP_1Tex (base.x,
-                        base.y,
-                        base.width,
-                        base.height,
-                        _texture2D->GetDeviceTexture(),
-                        texxform,
-                        _textColor);
+                       base.y + ((base.height - _cached_extent_height)/2),
+                       base.width,
+                       base.height,
+                       _texture2D->GetDeviceTexture(),
+                       texxform,
+                       _textColor);
   
   gfxContext.GetRenderStates ().SetBlend (alpha, src, dest);
   
@@ -223,6 +231,7 @@
   int width = 0;
   int height = 0;
   GetTextExtents (width, height);
+  SetMinimumHeight (height);
   NeedRedraw ();
   sigFontChanged.emit (this);
 }

=== modified file 'src/StaticCairoText.h'
--- src/StaticCairoText.h	2011-02-21 23:00:30 +0000
+++ src/StaticCairoText.h	2011-02-24 13:01:50 +0000
@@ -106,7 +106,7 @@
 
       int            _pre_layout_width;
       int            _pre_layout_height;
-
+      
       void GetTextExtents (const TCHAR* font,
                            int&         width,
                            int&         height);

=== modified file 'src/unitya11y.cpp'
--- src/unitya11y.cpp	2011-02-23 12:03:48 +0000
+++ src/unitya11y.cpp	2011-02-23 17:22:58 +0000
@@ -20,6 +20,7 @@
 #include <gio/gio.h>
 #include <gmodule.h>
 #include <stdio.h>
+#include <gconf/gconf-client.h>
 
 #include "unitya11y.h"
 #include "unity-util-accessible.h"
@@ -43,6 +44,11 @@
 
 static gboolean a11y_initialized = FALSE;
 
+#define INIT_METHOD "gnome_accessibility_module_init"
+#define A11Y_GCONF_KEY "/desktop/gnome/interface/accessibility"
+#define AT_SPI_SCHEMA "org.a11y.atspi"
+#define ATK_BRIDGE_LOCATION_KEY "atk-bridge-location"
+
 static void
 unity_a11y_restore_environment (void)
 {
@@ -56,12 +62,6 @@
   g_type_class_unref (g_type_class_ref (UNITY_TYPE_UTIL_ACCESSIBLE));
 }
 
-#define INIT_METHOD "gnome_accessibility_module_init"
-#define DESKTOP_SCHEMA "org.gnome.desktop.interface"
-#define ACCESSIBILITY_ENABLED_KEY "toolkit-accessibility"
-#define AT_SPI_SCHEMA "org.a11y.atspi"
-#define ATK_BRIDGE_LOCATION_KEY "atk-bridge-location"
-
 static gboolean
 has_gsettings_schema (const gchar *schema)
 {
@@ -87,19 +87,19 @@
 static gboolean
 should_enable_a11y (void)
 {
-  GSettings *desktop_settings = NULL;
+  GConfClient *client = NULL;
   gboolean value = FALSE;
-
-  if (g_getenv ("UNITY_A11Y_DISABLE"))
-    return FALSE;
-
-  if (!has_gsettings_schema (DESKTOP_SCHEMA))
-    return FALSE;
-   
-  desktop_settings = g_settings_new (DESKTOP_SCHEMA);
-  value = g_settings_get_boolean (desktop_settings, ACCESSIBILITY_ENABLED_KEY);
-
-  g_object_unref (desktop_settings);
+  GError *error = NULL;
+
+  client = gconf_client_get_default ();
+  value = gconf_client_get_bool (client, A11Y_GCONF_KEY, &error);
+  if (error != NULL)
+    {
+      g_warning ("Error getting gconf variable %s, a11y disabled by default",
+                 A11Y_GCONF_KEY);
+      g_error_free (error);
+    }
+  g_object_unref (client);
 
   return value;
 }
@@ -355,11 +355,6 @@
 
   unity_a11y_restore_environment ();
 
-  /* FIXME: gsettings is causing some crashes checking if a11y is
-     enabled, so we are move to gconf, meanwhile we require a sanity
-     commit. */
-  return;
-
   if (!should_enable_a11y ())
     return;
 

=== modified file 'tools/autopilot.py'
--- tools/autopilot.py	2011-02-10 18:35:01 +0000
+++ tools/autopilot.py	2011-02-25 15:13:39 +0000
@@ -112,8 +112,8 @@
 class UnityTests(object):
     '''Runs a series of unity actions, triggering GL calls'''
 
-    _bfb_x = 24
-    _bfb_y = 10
+    _bfb_x = 0
+    _bfb_y = 0
 	
     # this is totally lame. This should not be hard coded, but until I can get
     # unity to run in gdb and debug why introspection is crashing and hardlocking

